import { 
  select, 
  csv, 
  scaleLinear, 
  extent, 
  axisLeft,
	axisBottom,
	format} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

// acceleration: "12"
//cylinders: "8"
//displacement: "307"
//horsepower: "130"
//mpg: "18"
//name: "chevrolet chevelle malibu"
//origin: "USA"
//weight: "3504"
//year: "1970"

const render = data => {
  const title = 'Cars: Horsepower vs Weight';
  const xValue = d => d.horsepower;
  const xAxisLabel = 'Horsepower';
  const yValue = d => d.weight;
  const yAxisLabel = 'Weight';
  const circleRadius = 10;

  const margin = {top:60, right:40, bottom:100, left:150};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue).reverse())
  	.range([0, innerHeight])
  	.nice();

  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(20);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.select('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.text(yAxisLabel)
  	.attr('x', -innerHeight / 2)
  	.attr('text-anchor', 'middle')
  	.attr('y', -100)
  	.attr('transform', `rotate(-90)`);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('fill', 'black')
  	.text(xAxisLabel)
  	.attr('x', innerWidth / 2)
  	.attr('y', 80);
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  	.attr('cy', d => yScale(yValue(d)))
  	.attr('cx', d => xScale(xValue(d)))
  	.attr('r', circleRadius);
  
  g.append('text')
  	.attr('class', 'title')
  	.text(title)
  	.attr('y', -10);
};

csv('https://vizhub.com/curran/datasets/auto-mpg.csv')
  .then(data => {
    data.forEach(d => {
      d.mpg = +d.mpg;
      d.acceleration = +d.acceleration;
      d.cylinders = +d.cylinders;
      d.horsepower = +d.horsepower;
      d.displacement = +d.displacement;
      d.weight = +d.weight;
      d.year = +d.year;
    });
    render(data);
  });